# mannaggia-bot 👼

<p align="center">
  <img src="/assets/logo.png" width="128" height="128" />
</p>

<p align="center">~ The official Telegram bot for mannaggia-py ~</p>
<p align="center">
  <a href="https://ko-fi.com/veeso" target="_blank">Ko-fi</a>
  ·
  <a href="#get-started-">Setup</a>
  ·
  <a href="https://github.com/veeso/mannaggia-py" target="_blank">mannaggia-py</a>
</p>

<p align="center">Developed by <a href="https://veeso.github.io/" target="_blank">@veeso</a></p>
<p align="center">Current version: 0.1.0 (23/08/2022)</p>

<p align="center">
  <a href="http://www.wtfpl.net/about/"
    ><img
      src="https://img.shields.io/badge/License-WTFPL-blue.svg"
      alt="License-WTFPL"
  /></a>
  <a href="https://github.com/veeso/mannaggia-bot/stargazers"
    ><img
      src="https://img.shields.io/github/stars/veeso/mannaggia-bot.svg"
      alt="Repo stars"
  /></a>
  <a href="https://pepy.tech/project/mannaggia-bot"
    ><img
      src="https://pepy.tech/badge/mannaggia-bot"
      alt="Downloads counter"
  /></a>
  <a href="https://pypi.org/project/mannaggia-bot/"
    ><img
      src="https://badge.fury.io/py/mannaggia-bot.svg"
      alt="Latest version"
  /></a>
  <a href="https://ko-fi.com/veeso">
    <img
      src="https://img.shields.io/badge/donate-ko--fi-red"
      alt="Ko-fi"
  /></a>
</p>

---

## About mannaggia-bot

Mannaggia-bot is the Telegram bot for [mannaggia-py](https://github.com/veeso/mannaggia-py)

## Command API 🐷

- `/mannaggia`

    Send an audio with a random `mannaggia a <random_name>`

- `/mannaggia <name>`

    Send an audio saying `mannaggia a <name>`

## Get started 🚀

### For users

Scan this QR code or go to this URL <https://t.me/mannaggiapy_bot> to start a chat with Big Luca bot, then add it to any group or chat directly with him.

![telegram-qr](assets/telegram-qr.webp)

### For developers

1. Install mannaggia-bot with pip

    ```sh
    pip3 install mannaggia-bot
    ```

2. Run mannaggia

    ```sh
    export LOG_LEVEL="info"
    export TELEGRAM_API_KEY="..."
    mannaggia-bot
    ```

In case you're missing some dependencies after installation, run:

```sh
pip3 install -r requirements.txt
```

---

## Support the developer ☕

If you like mannaggia-bot and you're grateful for the work I've done, please consider a little donation 🥳

You can make a donation with one of these platforms:

[![ko-fi](https://img.shields.io/badge/Ko--fi-F16061?style=for-the-badge&logo=ko-fi&logoColor=white)](https://ko-fi.com/veeso)
[![PayPal](https://img.shields.io/badge/PayPal-00457C?style=for-the-badge&logo=paypal&logoColor=white)](https://www.paypal.me/chrisintin)
[![bitcoin](https://img.shields.io/badge/Bitcoin-ff9416?style=for-the-badge&logo=bitcoin&logoColor=white)](https://btc.com/bc1qvlmykjn7htz0vuprmjrlkwtv9m9pan6kylsr8w)
[![litecoin](https://img.shields.io/badge/Litecoin-345d9d?style=for-the-badge&logo=Litecoin&logoColor=white)](https://blockchair.com/litecoin/address/ltc1q89a7f859gt7nuekvnuuc25wapkq2f8ny78mp8l)
[![ethereum](https://img.shields.io/badge/Ethereum-3C3C3D?style=for-the-badge&logo=Ethereum&logoColor=white)](https://etherscan.io/address/0xE57E761Aa806c9afe7e06Fb0601B17beC310f9c4)

---

## License 📜

Licensed under the **DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE**, you can find [HERE](LICENSE) the entire license
